@@ -466,7 +466,7 @@ def partition_by_counts(
         ...     sequence,
         ...     [2, 3, 5],
         ...     cyclic=False,
-        ...     overhang=abjad.Exact,
+        ...     overhang=abjad.EXACT,
         ... )
 
         >>> for part in parts:
@@ -485,7 +485,7 @@ def partition_by_counts(
         ...     sequence,
         ...     [2],
         ...     cyclic=True,
-        ...     overhang=abjad.Exact,
+        ...     overhang=abjad.EXACT,
         ... )
 
         >>> for part in parts:
@@ -621,9 +621,9 @@ def partition_by_counts(
     if part:
         if overhang is True:
             result.append(part)
-        elif overhang is _enums.Exact and len(part) == count:
+        elif overhang is _enums.EXACT and len(part) == count:
             result.append(part)
-        elif overhang is _enums.Exact and len(part) != count:
+        elif overhang is _enums.EXACT and len(part) != count:
             raise Exception("sequence does not partition exactly.")
     if reversed_:
         result_ = []
@@ -671,7 +671,7 @@ def partition_by_ratio_of_lengths(sequence, ratio) -> list:
     ratio = _ratio.Ratio(ratio)
     length = len(sequence)
     counts = ratio.partition_integer(length)
-    parts = partition_by_counts(sequence, counts, cyclic=False, overhang=_enums.Exact)
+    parts = partition_by_counts(sequence, counts, cyclic=False, overhang=_enums.EXACT)
     return parts
 
 
@@ -810,11 +810,11 @@ def partition_by_ratio_of_weights(sequence, weights) -> list:
     weights_parts = _ratio.Ratio(weights).partition_integer(list_weight)
     cumulative_weights = _math.cumulative_sums(weights_parts, start=None)
     items = []
-    sublist: typing.List[typing.Any] = []
+    sublist: list[typing.Any] = []
     items.append(sublist)
     current_cumulative_weight = cumulative_weights.pop(0)
     for item in sequence:
-        if not isinstance(item, (int, float, quicktions.Fraction)):
+        if not isinstance(item, int | float | quicktions.Fraction):
             raise TypeError(f"must be number: {item!r}.")
         sublist.append(item)
         while current_cumulative_weight <= _math.weight(flatten(items, depth=-1)):
@@ -834,7 +834,7 @@ def partition_by_weights(
     *,
     cyclic=False,
     overhang=False,
-    allow_part_weights=_enums.Exact,
+    allow_part_weights=_enums.EXACT,
 ) -> list:
     r"""
     Partitions sequence by ``weights`` exactly.
@@ -915,7 +915,7 @@ def partition_by_weights(
         ...     [10, 4],
         ...     cyclic=False,
         ...     overhang=False,
-        ...     allow_part_weights=abjad.Less,
+        ...     allow_part_weights=abjad.LESS,
         ... ):
         ...     item
         ...
@@ -932,7 +932,7 @@ def partition_by_weights(
         ...     [10, 4],
         ...     cyclic=False,
         ...     overhang=True,
-        ...     allow_part_weights=abjad.Less,
+        ...     allow_part_weights=abjad.LESS,
         ... ):
         ...     item
         ...
@@ -950,7 +950,7 @@ def partition_by_weights(
         ...     [10, 5],
         ...     cyclic=True,
         ...     overhang=False,
-        ...     allow_part_weights=abjad.Less,
+        ...     allow_part_weights=abjad.LESS,
         ... ):
         ...     item
         ...
@@ -971,7 +971,7 @@ def partition_by_weights(
         ...     [10, 5],
         ...     cyclic=True,
         ...     overhang=True,
-        ...     allow_part_weights=abjad.Less,
+        ...     allow_part_weights=abjad.LESS,
         ... ):
         ...     item
         ...
@@ -994,7 +994,7 @@ def partition_by_weights(
         ...     [10, 4],
         ...     cyclic=False,
         ...     overhang=False,
-        ...     allow_part_weights=abjad.More,
+        ...     allow_part_weights=abjad.MORE,
         ... ):
         ...     item
         ...
@@ -1011,7 +1011,7 @@ def partition_by_weights(
         ...     [10, 4],
         ...     cyclic=False,
         ...     overhang=True,
-        ...     allow_part_weights=abjad.More,
+        ...     allow_part_weights=abjad.MORE,
         ... ):
         ...     item
         ...
@@ -1029,7 +1029,7 @@ def partition_by_weights(
         ...     [10, 4],
         ...     cyclic=True,
         ...     overhang=False,
-        ...     allow_part_weights=abjad.More,
+        ...     allow_part_weights=abjad.MORE,
         ... ):
         ...     item
         ...
@@ -1048,7 +1048,7 @@ def partition_by_weights(
         ...     [10, 4],
         ...     cyclic=True,
         ...     overhang=True,
-        ...     allow_part_weights=abjad.More,
+        ...     allow_part_weights=abjad.MORE,
         ... ):
         ...     item
         ...
@@ -1060,7 +1060,7 @@ def partition_by_weights(
 
     Returns list of sequences.
     """
-    if allow_part_weights is _enums.Exact:
+    if allow_part_weights is _enums.EXACT:
         candidate = type(sequence)(sequence)
         candidate = split(candidate, weights, cyclic=cyclic, overhang=overhang)
         flattened_candidate = flatten(candidate, depth=-1)
@@ -1068,7 +1068,7 @@ def partition_by_weights(
             return candidate
         else:
             raise Exception("can not partition exactly.")
-    elif allow_part_weights is _enums.More:
+    elif allow_part_weights is _enums.MORE:
         if not cyclic:
             result = _partition_sequence_once_by_weights_at_least(
                 sequence, weights, overhang=overhang
@@ -1077,7 +1077,7 @@ def partition_by_weights(
             result = _partition_sequence_cyclically_by_weights_at_least(
                 sequence, weights, overhang=overhang
             )
-    elif allow_part_weights is _enums.Less:
+    elif allow_part_weights is _enums.LESS:
         if not cyclic:
             result = _partition_sequence_once_by_weights_at_most(
                 sequence, weights, overhang=overhang
@@ -1182,10 +1182,10 @@ def split(sequence, weights, cyclic=False, overhang=False) -> list:
     """
     result = []
     current_index = 0
-    current_piece: typing.List[typing.Any] = []
+    current_piece: list[typing.Any] = []
     if cyclic:
         weights = repeat_to_weight(
-            weights, _math.weight(sequence), allow_total=_enums.Less
+            weights, _math.weight(sequence), allow_total=_enums.LESS
         )
     for weight in weights:
         current_piece_weight = _math.weight(current_piece)
@@ -1335,7 +1335,7 @@ def group_by(sequence, predicate=None) -> list:
     ..  container:: example
 
         >>> staff = abjad.Staff("c'8 d' d' e' e' e'")
-        >>> predicate = lambda _: abjad.PitchSet.from_pitches([_])
+        >>> predicate = lambda _: abjad.PitchSet([_])
         >>> sequence = list(staff)
         >>> for item in abjad.sequence.group_by(sequence, predicate):
         ...     item
@@ -1360,6 +1360,25 @@ def group_by(sequence, predicate=None) -> list:
     return items
 
 
+def has_duplicates(sequence):
+    """
+    Is true when ``sequence`` has duplicates.
+
+    ..  container::
+
+        >>> abjad.sequence.has_duplicates([0, 1, 2, 3, 4])
+        False
+
+        >>> abjad.sequence.has_duplicates([0, 1, 2, 3, 3])
+        True
+
+        >>> abjad.sequence.has_duplicates([0, 1, 0, 1, 0])
+        True
+
+    """
+    return len(set(sequence)) < len(sequence)
+
+
 def is_decreasing(sequence, strict=True) -> bool:
     """
     Is true when sequence decreases.
@@ -1591,7 +1610,7 @@ def map(sequence, operand=None):
     return type(sequence)(items)
 
 
-def nwise(sequence, n=2, cyclic=False, wrapped=False) -> typing.Generator:
+def nwise(sequence, n=2, cyclic=False, wrapped=False) -> typing.Iterator:
     """
     Iterates ``sequence`` ``n`` at a time.
 
@@ -1752,7 +1771,7 @@ def nwise(sequence, n=2, cyclic=False, wrapped=False) -> typing.Generator:
             current += 1
             current %= len_sequence
     elif wrapped:
-        first_n_minus_1: typing.List[typing.Any] = []
+        first_n_minus_1: list[typing.Any] = []
         item_buffer = []
         for item in sequence:
             item_buffer.append(item)
@@ -1953,7 +1972,7 @@ def repeat_to_length(sequence, length=None, start=0):
     return type(sequence)(items[start:stop_index])
 
 
-def repeat_to_weight(sequence, weight, allow_total=_enums.Exact):
+def repeat_to_weight(sequence, weight, allow_total=_enums.EXACT):
     """
     Repeats sequence to ``weight``.
 
@@ -1966,12 +1985,12 @@ def repeat_to_weight(sequence, weight, allow_total=_enums.Exact):
 
         Repeats sequence to weight of 23 more:
 
-        >>> abjad.sequence.repeat_to_weight([5, -5, -5], 23, allow_total=abjad.More)
+        >>> abjad.sequence.repeat_to_weight([5, -5, -5], 23, allow_total=abjad.MORE)
         [5, -5, -5, 5, -5]
 
         Repeats sequence to weight of 23 or less:
 
-        >>> abjad.sequence.repeat_to_weight([5, -5, -5], 23, allow_total=abjad.Less)
+        >>> abjad.sequence.repeat_to_weight([5, -5, -5], 23, allow_total=abjad.LESS)
         [5, -5, -5, 5]
 
         >>> sequence = [abjad.NonreducedFraction(3, 16)]
@@ -1986,7 +2005,7 @@ def repeat_to_weight(sequence, weight, allow_total=_enums.Exact):
     Returns sequence type.
     """
     assert 0 <= weight
-    if allow_total is _enums.Exact:
+    if allow_total is _enums.EXACT:
         sequence_weight = _math.weight(sequence)
         complete_repetitions = int(math.ceil(float(weight) / float(sequence_weight)))
         items = list(sequence)
@@ -2009,7 +2028,7 @@ def repeat_to_weight(sequence, weight, allow_total=_enums.Exact):
                     break
             else:
                 break
-    elif allow_total is _enums.Less:
+    elif allow_total is _enums.LESS:
         items = [sequence[0]]
         i = 1
         while _math.weight(items) < weight:
@@ -2018,7 +2037,7 @@ def repeat_to_weight(sequence, weight, allow_total=_enums.Exact):
         if weight < _math.weight(items):
             items = items[:-1]
         return type(sequence)(items)
-    elif allow_total is _enums.More:
+    elif allow_total is _enums.MORE:
         items = [sequence[0]]
         i = 1
         while _math.weight(items) < weight:
@@ -2106,13 +2125,13 @@ def replace_at(sequence, indices, new_material):
     index_values, index_period = indices
     assert isinstance(index_values, collections.abc.Sequence)
     index_values = list(index_values)
-    assert isinstance(index_period, (int, type(None)))
+    assert isinstance(index_period, int | type(None))
     assert isinstance(new_material, collections.abc.Sequence)
     assert len(new_material) == 2
     material_values, material_period = new_material
     assert isinstance(material_values, collections.abc.Sequence)
     material_values = list(material_values)
-    assert isinstance(material_period, (int, type(None)))
+    assert isinstance(material_period, int | type(None))
     maxsize = sys.maxsize
     if index_period is None:
         index_period = maxsize
@@ -2252,9 +2271,9 @@ def reverse(sequence, recurse=False):
         >>> for item in abjad.sequence.reverse(sequence, recurse=True):
         ...     item
         ...
-        PitchClassSegment(items=[5, 4], item_class=NumberedPitchClass)
+        PitchClassSegment([5, 4])
         NumberedPitch(3)
-        PitchClassSegment(items=[2, 1], item_class=NumberedPitchClass)
+        PitchClassSegment([2, 1])
 
     Returns sequence type.
     """
@@ -2590,7 +2609,7 @@ def zip(sequences, cyclic=False, truncate=True) -> list[tuple]:
     for item in sequences:
         if not isinstance(item, collections.abc.Iterable):
             raise Exception(f"must be iterable: {item!r}.")
-    items: typing.List[typing.Any] = []
+    items: list[typing.Any] = []
     if cyclic:
         if not min(len(_) for _ in sequences):
             return items
